@@ -114,9 +114,6 @@ void cryptopan_getopt(int* argc, char** argv[])
 
     while ((c = getopt(*argc, *argv, "?k:K:i:I:a:A:Dcsp:6")) != EOF) {
         switch (c) {
-        case '?':
-            cryptopan_usage();
-            exit(0);
         case 'k':
             if (strlen(optarg) != 16) {
                 usage("key must be 16 characters long");
@@ -210,8 +207,13 @@ void cryptopan_getopt(int* argc, char** argv[])
         case '6':
             encrypt_v6 = 1;
             break;
-        default:
+        case '?':
             cryptopan_usage();
+            if (!optopt || optopt == '?') {
+                exit(0);
+            }
+            // fallthrough
+        default:
             exit(1);
         }
     }
