@@ -316,9 +316,6 @@ void parse_args(int argc, char* argv[])
         case 'I':
             wanticmp = TRUE;
             break;
-        case '?':
-            help_2();
-            exit(0);
         case 'V':
             printf("%s version %s\n", ProgramName, PACKAGE_VERSION);
             exit(0);
@@ -654,16 +651,23 @@ void parse_args(int argc, char* argv[])
         case 'y':
 #ifdef USE_SECCOMP
             use_seccomp = TRUE;
+            break;
 #else
             usage("seccomp-bpf not enabled");
 #endif
-            break;
         case 'M':
             monitor_mode = TRUE;
             break;
         case 'D':
             immediate_mode = TRUE;
             break;
+        case '?':
+            if (!optopt || optopt == '?') {
+                help_2();
+                options_free(&options);
+                exit(0);
+            }
+            // fallthrough
         default:
             usage("unrecognized command line option");
         }
