@@ -104,18 +104,14 @@ static int dns_protocol_handler(tcpreasm_t* t, u_char* segment, uint16_t dnslen,
             }
 
             t->bfb_buf[t->bfb_at++] = dnslen >> 8;
-            t->bfb_buf[t->bfb_at++] = dnslen & 0xff;
+            t->bfb_buf[t->bfb_at++] = dnslen & 0xff; //NOSONAR
             memcpy(&t->bfb_buf[t->bfb_at], segment, dnslen);
             t->bfb_at += dnslen;
             t->seq_bfb += 2 + dnslen;
         } else {
             /* add segment for later processing */
             dfprintf(1, "dns_protocol_handler: add bfb_seg: seq = %u, len = %d", seq, dnslen);
-            for (s = 0;; s++) {
-                if (s >= MAX_TCP_SEGS) {
-                    dfprintf(1, "dns_protocol_handler: out of bfbsegs");
-                    return 1;
-                }
+            for (s = 0; s < MAX_TCP_SEGS; s++) {
                 if (t->bfb_seg[s])
                     continue;
                 t->bfb_seg[s]      = calloc(1, sizeof(tcp_segbuf_t) + dnslen);
@@ -126,12 +122,18 @@ static int dns_protocol_handler(tcpreasm_t* t, u_char* segment, uint16_t dnslen,
                     s, t->bfb_seg[s]->seq, t->bfb_seg[s]->len);
                 break;
             }
+            if (s >= MAX_TCP_SEGS) {
+                dfprintf(1, "dns_protocol_handler: out of bfbsegs");
+                return 1;
+            }
             return 0;
         }
 
         for (;;) {
             /* process the buffer, extract dnslen and try and parse */
-            for (at = 0, len = t->bfb_at;;) {
+            at  = 0;
+            len = t->bfb_at;
+            for (;;) {
                 dfprintf(1, "dns_protocol_handler: processing at = %zu, len = %zu", at, len);
                 if (len < 2) {
                     dfprintf(1, "dns_protocol_handler: bfb need more for dnslen");
@@ -210,11 +212,7 @@ static int dns_protocol_handler(tcpreasm_t* t, u_char* segment, uint16_t dnslen,
 
             dfprintf(1, "dns_protocol_handler: bfb fill at %zu", t->bfb_at);
             /* see if we can fill the buffer */
-            for (s = 0;; s++) {
-                if (s >= MAX_TCP_SEGS) {
-                    dfprintf(1, "dns_protocol_handler: bfb need next seg");
-                    return 0;
-                }
+            for (s = 0; s < MAX_TCP_SEGS; s++) {
                 if (!t->bfb_seg[s])
                     continue;
 
@@ -235,8 +233,11 @@ static int dns_protocol_handler(tcpreasm_t* t, u_char* segment, uint16_t dnslen,
                     break;
                 }
             }
+            if (s >= MAX_TCP_SEGS) {
+                dfprintf(1, "dns_protocol_handler: bfb need next seg");
+                return 0;
+            }
         }
-        return 0;
     }
 #endif
 
@@ -373,31 +374,7 @@ int pcap_handle_tcp_segment(u_char* segment, int len, uint32_t seq, tcpstate_ptr
      * Welcome to reassembly-land.
      */
     /* find the message to which the first byte of this segment belongs */
-    for (m = 0;; m++) {
-        if (m >= MAX_TCP_MSGS) {
-            /* seg does not match any msgbuf; just hold on to it. */
-            dfprintf(1, "pcap_handle_tcp_segment: %s", "seg does not match any msgbuf");
-
-            if (seq - tcpstate->seq_start > MAX_TCP_WINDOW_SIZE) {
-                dfprintf(1, "pcap_handle_tcp_segment: %s %u %u", "seg is outside window; discarding", seq, tcpstate->seq_start);
-                return 1;
-            }
-            for (s = 0;; s++) {
-                if (s >= MAX_TCP_SEGS) {
-                    dfprintf(1, "pcap_handle_tcp_segment: %s", "out of segbufs");
-                    return 1;
-                }
-                if (tcpstate->segbuf[s])
-                    continue;
-                tcpstate->segbuf[s]      = calloc(1, sizeof(tcp_segbuf_t) + len);
-                tcpstate->segbuf[s]->seq = seq;
-                tcpstate->segbuf[s]->len = len;
-                memcpy(tcpstate->segbuf[s]->buf, segment, len);
-                dfprintf(1, "pcap_handle_tcp_segment: new segbuf %d: seq = %u, len = %d",
-                    s, tcpstate->segbuf[s]->seq, tcpstate->segbuf[s]->len);
-                return 0;
-            }
-        }
+    for (m = 0; m < MAX_TCP_MSGS; m++) {
         if (!tcpstate->msgbuf[m])
             continue;
         segoff = seq - tcpstate->msgbuf[m]->seq;
@@ -415,6 +392,28 @@ int pcap_handle_tcp_segment(u_char* segment, int len, uint32_t seq, tcpstate_ptr
             break;
         }
     }
+    if (m >= MAX_TCP_MSGS) {
+        /* seg does not match any msgbuf; just hold on to it. */
+        dfprintf(1, "pcap_handle_tcp_segment: %s", "seg does not match any msgbuf");
+
+        if (seq - tcpstate->seq_start > MAX_TCP_WINDOW_SIZE) {
+            dfprintf(1, "pcap_handle_tcp_segment: %s %u %u", "seg is outside window; discarding", seq, tcpstate->seq_start);
+            return 1;
+        }
+        for (s = 0; s < MAX_TCP_SEGS; s++) {
+            if (tcpstate->segbuf[s])
+                continue;
+            tcpstate->segbuf[s]      = calloc(1, sizeof(tcp_segbuf_t) + len);
+            tcpstate->segbuf[s]->seq = seq;
+            tcpstate->segbuf[s]->len = len;
+            memcpy(tcpstate->segbuf[s]->buf, segment, len);
+            dfprintf(1, "pcap_handle_tcp_segment: new segbuf %d: seq = %u, len = %d",
+                s, tcpstate->segbuf[s]->seq, tcpstate->segbuf[s]->len);
+            return 0;
+        }
+        dfprintf(1, "pcap_handle_tcp_segment: %s", "out of segbufs");
+        return 1;
+    }
 
     /* Reassembly algorithm adapted from RFC 815. */
     for (i = 0; i < MAX_TCP_HOLES; i++) {
@@ -443,16 +442,16 @@ int pcap_handle_tcp_segment(u_char* segment, int len, uint32_t seq, tcpstate_ptr
         if (segoff > hole_start) {
             /* create a new hole before the segment */
             int j;
-            for (j = 0;; j++) {
-                if (j == MAX_TCP_HOLES) {
-                    dfprintf(1, "pcap_handle_tcp_segment: %s", "out of hole descriptors");
-                    return 1;
-                }
+            for (j = 0; j < MAX_TCP_HOLES; j++) {
                 if (tcpstate->msgbuf[m]->hole[j].len == 0) {
                     newhole = &tcpstate->msgbuf[m]->hole[j];
                     break;
                 }
             }
+            if (j >= MAX_TCP_HOLES) {
+                dfprintf(1, "pcap_handle_tcp_segment: %s", "out of hole descriptors");
+                return 1;
+            }
             tcpstate->msgbuf[m]->holes++;
             newhole->start = hole_start;
             newhole->len   = segoff - hole_start;
